@@ -30,8 +30,9 @@ pub fn get_optimize_config_from_args(matches: &ArgMatches) -> OptimizeConfig {
     let mut cfg = match matches.value_of("OPT_MODE").unwrap_or("2") {
         "1" => OptimizeConfig::o1(),
         "2" => OptimizeConfig::o2(),
-        "3" => OptimizeConfig::o2(),
-        "s" => OptimizeConfig::o2(),
+        "3" => OptimizeConfig::o3(),
+        "s" => OptimizeConfig::size(),
+        "wtf" => OptimizeConfig::wtf(),
         _ => OptimizeConfig::o0(),
     };
 
@@ -39,5 +40,13 @@ pub fn get_optimize_config_from_args(matches: &ArgMatches) -> OptimizeConfig {
         cfg.jit_level = Some(jit_level.to_string());
     }
 
+    if matches.is_present("WRAPPING_IS_UB") {
+        cfg.wrapping_is_ub = true;
+    }
+
+    if matches.is_present("DEBUG_OPT") {
+        cfg.debug = true;
+    }
+
     cfg
 }
